"use client";
import { FC, PropsWithChildren, ReactNode } from "react";
import Router from 'next/router';
import { useRouter } from "@/i18n";
import clsx from "clsx";
import styles from "./style.module.scss";

/**
 * @description 自定义头部返回组件
 * @param {string} title header标题
 * @param {ReactNode} children 插槽内容
 * @param {() => ReactNode} headerRender 自定义渲染
 */
export interface HeaderBackProps {
    title?: string;
    children?: ReactNode;
    headerRender?: () => ReactNode;
}

const HeaderBack: FC<PropsWithChildren<HeaderBackProps>> = ({title = '', children}) => {
    const iconClassName1 = clsx({
        [styles.iconfontIcon1]: true,
    },'iconfont icon-xiangzuo1');
    const iconClassName2 = clsx({
        [styles.iconfontIcon2]: true,
    },'iconfont icon-company_nav_icon_home');

    const router:any = useRouter()
    const goPage = (path = '') => {
        if (path) {
            router.replace('/')
            return
        }
        router.back()
    }

    return (
        <div className={styles.headerBack}>
            <div className={styles.left} onClick={() => goPage()}>
                <span className={iconClassName1}></span>
            </div>
            {title && <span className={styles.title}>{title}</span>}
            {children}
            <span className={styles.right} onClick={() => goPage('home')}>
                <span className={iconClassName2}></span>
            </span>
        </div>
    );
};

export default HeaderBack;
